/*
 *  Version: 1.0
 *
 *  The contents of this file are subject to the OpenVPMS License Version
 *  1.0 (the 'License'); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *  http://www.openvpms.org/license/
 *
 *  Software distributed under the License is distributed on an 'AS IS' basis,
 *  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 *  for the specific language governing rights and limitations under the
 *  License.
 *
 *  Copyright 2006 (C) OpenVPMS Ltd. All Rights Reserved.
 *
 *  $Id: MessageDialog.java 3790 2010-08-03 11:23:00Z tanderson $
 */

package org.openvpms.web.component.dialog;

import nextapp.echo2.app.Label;
import nextapp.echo2.app.Row;
import org.openvpms.web.component.focus.FocusCommand;
import org.openvpms.web.component.util.LabelFactory;
import org.openvpms.web.component.util.RowFactory;


/**
 * A generic modal dialog that displays a message.
 *
 * @author <a href="mailto:support@openvpms.org">OpenVPMS Team</a>
 * @version $LastChangedDate: 2010-08-03 21:23:00 +1000 (Tue, 03 Aug 2010) $
 */
public abstract class MessageDialog extends PopupDialog {

    /**
     * The message.
     */
    private final String message;

    /**
     * Dialog style name.
     */
    private static final String STYLE = "MessageDialog";

    /**
     * The focus, prior to the dialog being shown.
     */
    private FocusCommand focus;


    /**
     * Creates a new <code>MessageDialog</code>.
     *
     * @param title   the dialog title
     * @param message the message to display
     * @param buttons the buttons to display
     */
    public MessageDialog(String title, String message, String[] buttons) {
        this(title, message, STYLE, buttons);
    }

    /**
     * Creates a new <code>MessageDialog</code>.
     *
     * @param title   the dialog title
     * @param message the message to display
     * @param style   the dialog style
     * @param buttons the buttons to display
     */
    public MessageDialog(String title, String message, String style,
                         String[] buttons) {
        super(title, style, buttons);
        this.message = message;
        setModal(true);
        focus = new FocusCommand();
    }

    /**
     * Processes a user request to close the window (via the close button).
     * <p/>
     * This restores the previous focus
     */
    @Override
    public void userClose() {
        focus.restore();
        super.userClose();
    }

    /**
     * Lays out the component prior to display.
     */
    @Override
    protected void doLayout() {
        Label content = LabelFactory.create(true, true);
        content.setText(message);
        Row row = RowFactory.create("Inset", content);
        getLayout().add(row);
    }

    /**
     * Returns the message.
     *
     * @return the message
     */
    protected String getMessage() {
        return message;
    }

}
